import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()
LICENSE = (HERE / 'LICENSE').read_text()

setup(
    name="hasiicommon",
    version="0.0.3",
    author='Humberto A. Sanchez II',
    author_email='Humberto.A.Sanchez.II@gmail.com',
    maintainer='Humberto A. Sanchez II',
    maintainer_email='humberto.a.sanchez.ii@gmail.com',
    description='Humberto`s Common Stuff',
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/hasii2011/hasiicommon",
    package_data={
        'hasiicommon':           ['py.typed'],
        'hasiicommon.resources':              ['py.typed'],
        'hasiicommon.resources.images':       ['py.typed'],
        'hasiicommon.resources.images.icons': ['py.typed'],
        'hasiicommon.resources.images.icons.embedded16': ['py.typed'],
        'hasiicommon.resources.images.icons.embedded32': ['py.typed'],

        'hasiicommon.ui':        ['py.typed'],
        'hasiicommon.ui.widget': ['py.typed'],
    },

    packages=[
        'hasiicommon',
        'hasiicommon.resources',
        'hasiicommon.ui', 'hasiicommon.ui.widgets'
    ],
    install_requires=['Deprecated~=1.2.13', 'wxPython~=4.2.0'],
)




from typing import List

from dataclasses import dataclass


@dataclass
class Position:

    x: int = 0
    y: int = 0

    @classmethod
    def deSerialize(cls, value: str) -> 'Position':

        position: Position = Position()

        xy: List[str] = value.split(sep=',')

        assert len(xy) == 2, 'Incorrectly formatted position'

        try:
            position.x = int(xy[0])
            position.y = int(xy[1])
        except ValueError as ve:
            print(f'Dimensions - {ve}.')
            position.x = 0
            position.y = 0

        return position

    def __str__(self):
        return f'{self.x},{self.y}'

    def __repr__(self):
        return self.__str__()
